@@ -52,7 +52,7 @@ tdsDataTypes = dict(enumerate((
 tdsDataTypes.update({
     0x19: DataType('tdsTypeSingleFloatWithUnit', None, 4, None),
     0x20: DataType('tdsTypeString', None, None, None),
-    0x21: DataType('tdsTypeBoolean', 'b', 8, np.bool8),
+    0x21: DataType('tdsTypeBoolean', 'b', 1, np.bool8),
     0x44: DataType('tdsTypeTimeStamp', 'Qq', 16, None),
     0xFFFFFFFF: DataType('tdsTypeDAQmxRawData', None, None, None)
 })
@@ -286,6 +286,14 @@ class _TdmsSegment(object):
                 o.data_size
                 for o in self.ordered_objects])
         total_data_size = self.next_segment_offset - self.raw_data_offset
+        if data_size < 0 or total_data_size < 0:
+            raise ValueError("Negative data size")
+        elif data_size == 0:
+            # Sometimes kTocRawData is set, but there isn't actually any data
+            if total_data_size != data_size:
+                raise ValueError("Zero channel data size but non-zero data "
+                        "length based on segment offset.")
+            return
         if total_data_size % data_size != 0:
             raise ValueError("Data size %d is not a multiple of the "
                     "chunk size %d" % (total_data_size, data_size))
@@ -413,6 +421,7 @@ class TdmsObject(object):
         elif self.raw_data_index == 0x00000000:
             pass
         else:
+            self.has_data = True
             index_length = self.raw_data_index
 
             # Read the data type
@@ -443,6 +452,7 @@ class TdmsObject(object):
         # Read data properties
         s = f.read(4)
         num_properties = struct.unpack("<L", s)[0]
+        log.debug("Reading %d properties" % num_properties)
         for i in range(num_properties):
             prop_name = read_string(f)
 
@@ -484,8 +494,10 @@ class TdmsObject(object):
         except KeyError:
             raise KeyError("Object does not have time properties available.")
 
-        return np.arange(
-                offset, offset + len(self.data) * increment, increment)
+        return np.linspace(
+                offset,
+                offset + (len(self.data) - 1) * increment,
+                len(self.data))
 
     def _new_segment_data(self):
         """Return a new array to read the data of the current section into"""
